@@ -20,11 +20,11 @@ from apafib.datasets import fetch_apa_data, load_BCN_IBEX, load_BCN_UK, load_BCN
      load_medical_costs, load_stroke, load_wind_prediction, load_titanic, load_crabs, \
      load_life_expectancy, load_electric_devices, load_energy, load_arxiv, load_attrition, \
      load_literature, load_translation, load_heart_failure, load_MNIST, load_darwin, \
-     load_bands, load_NASDAQ, load_sentiment, load_BCN_cesta, load_BCN_ruido
+     load_bands, load_NASDAQ, load_sentiment, load_BCN_cesta, load_BCN_ruido, load_credit_scoring
 
 from apafib.classifiers import BlackBoxClassifier, BlackBoxRegressor
 
-__version__ = '0.1.5'
+__version__ = '0.1.6'
 
 __all__ = ['fetch_apa_data', 
            'BlackBoxClassifier', 
@@ -52,4 +52,5 @@ __all__ = ['fetch_apa_data',
            'load_sentiment',
            'load_BCN_cesta',
            'load_BCN_ruido',
+           'load_credit_scoring'
            ]
\ No newline at end of file
